@@ -225,7 +225,11 @@ NS_IMETHODIMP nsScriptablePeer::Seek(double counter)
 NS_IMETHODIMP nsScriptablePeer::GetPlayState(PRInt32 * aPlayState)
 {
     printf("JS playState issued\n");
-    mPlugin->GetPlayState(aPlayState);
+    if (mPlugin != NULL) {
+    	mPlugin->GetPlayState(aPlayState);
+    } else {
+	*aPlayState = JS_STATE_UNDEFINED; 
+    }
     return NS_OK;
 }
 
@@ -264,6 +268,21 @@ NS_IMETHODIMP nsScriptablePeer::SetFilename(const char *aFilename)
     return NS_OK;
 }
 
+NS_IMETHODIMP nsScriptablePeer::GetSrc(char **aSrc)
+{
+    printf("JS src requested\n");
+    mPlugin->GetFilename(aSrc);
+    return NS_OK;
+}
+
+NS_IMETHODIMP nsScriptablePeer::SetSrc(const char *aSrc)
+{
+    printf("JS src issued\n");
+    mPlugin->SetFilename(aSrc);
+    return NS_OK;
+}
+
+
 NS_IMETHODIMP nsScriptablePeer::Open(const char *filename)
 {
     printf("JS filename issued\n");
@@ -435,6 +454,12 @@ NS_IMETHODIMP nsScriptablePeer::SetShowlogo(PRBool aShowlogo)
     return NS_OK;
 }
 
+NS_IMETHODIMP nsScriptablePeer::OnClick(const char *event)
+{
+    mPlugin->SetOnClick(event);
+    return NS_OK;
+}
+
 
 NS_IMETHODIMP nsScriptablePeer::GetControls(nsIScriptableWMPPlugin *
 					    *aControls)
