@@ -833,7 +833,7 @@ void buildPlaylist(nsPluginInstance * instance, char *file, Node * parent)
 		found = 1;
 	    }
 	    // simple playlist usually realmedia file
-	    if (strncasecmp(buffer, "rtsp", 4) == 0 && found == 0) {
+	    if (memmem(buffer_lower, size, "rtsp://", 7) != NULL && found == 0) {
 		if (DEBUG) {
 		    printf("Search RTSP File\n");
 		}
@@ -865,6 +865,40 @@ void buildPlaylist(nsPluginInstance * instance, char *file, Node * parent)
 		    }
 		}
 	    }
+	    // simple playlist usually realmedia file
+	    if (memmem(buffer_lower, size, "pnm://", 6) != NULL && found == 0) {
+		if (DEBUG) {
+		    printf("Search for PNM url File\n");
+		}
+		p = buffer_lower;
+		while (p != NULL) {
+		    i = size - ((long) p - (long) buffer_lower);
+		    p = (char *) memmem(p, i, "pnm://", 6);
+		    if (p == NULL) {
+			break;
+		    } else {
+			i = (long) p - (long) buffer_lower;
+			snprintf(url, 1024, "pnm://%s", buffer + i + 6);
+			sub = strchr(url, 0xd);	// terminate on CR
+			if (sub != NULL)
+			    sub[0] = '\0';
+			sub = strchr(url, 0xa);	// terminate on line feed
+			if (sub != NULL)
+			    sub[0] = '\0';
+			//sub = strchr(url, 0x20);	// terminate on space
+			sub = strchr(url, EOF);	// terminate on EOF
+			if (sub != NULL)
+			    sub[0] = '\0';
+			if (DEBUG)
+			    printf("URL: %s\n", url);
+			parent->playlist = 1;
+			addToList(instance, url, parent, -1, 0, -1,0);
+			p = p + strlen(url) + 1;
+			found = 1;
+		    }
+		}
+	    }
+
 	    // simple playlist, usually old windows media
 	    if ((strncasecmp(buffer, "http://", 7) == 0
 		 || memmem(buffer_lower, size, "http://", 7) != NULL)
