@@ -76,6 +76,7 @@ char *GetMIMEDescription()
 
 
     enable_mpeg = 1;
+    enable_mp3 = 1;
     enable_ogg = 1;
     enable_smil = 1;
     enable_helix = 1;
@@ -88,6 +89,7 @@ char *GetMIMEDescription()
     enable_pls = 0;
     use_custom_mime_types = 0;
 
+
     DEBUG = 0;			//set to 1 when debugging this function
     if (DEBUG)
 	printf("Reading config file for codecs\n");
@@ -523,6 +525,7 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
     int real_master_console = 0;
     char parse[1000];
     char *cp;
+    char *tmp;
 
     if (DEBUG)
 	printf("mimetype: %s\n", parameters->type);
@@ -629,8 +632,8 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 		}
 	    }
 
-	    if ((strncasecmp(parameters->argn[i], "href", 4) == 0)
-		|| (strncasecmp(parameters->argn[i], "qtsrc", 5) == 0)) {
+	    if (strncasecmp(parameters->argn[i], "href", 4) == 0) {
+
 		instance->href = strdup(parameters->argv[i]);
 		if (strncasecmp(parameters->argv[i], "file://", 7) == 0)
 		    fullyQualifyURL(instance, parameters->argv[i],
@@ -641,6 +644,26 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 		instance->state = STATE_HAVEURL;
 	    }
 
+	    if (strncasecmp(parameters->argn[i], "qtsrc", 5) == 0) {
+                instance->href = (char *)malloc(1024);
+                tmp = rindex(instance->url,'/');
+                if (tmp) {
+                    instance->href = strcpy(instance->href,instance->url);
+                    tmp = rindex(instance->href,'/');
+                    tmp[1] = '\0';
+		    instance->href = strncat(instance->href,parameters->argv[i],1024);
+                } else {
+		    instance->href = strcpy(instance->href,parameters->argv[i]);
+                }
+		if (strncasecmp(parameters->argv[i], "file://", 7) == 0)
+		    fullyQualifyURL(instance, parameters->argv[i],
+				    instance->href);
+		if (strstr(parameters->argv[i], "<") != NULL)
+		    fullyQualifyURL(instance, parameters->argv[i],
+				    instance->href);
+		instance->state = STATE_HAVEURL;
+	    }
+
             if (strncasecmp(parameters->argn[i], "autohref", 8) == 0) {
 
 		lowercase(parameters->argv[i]);
