@@ -733,6 +733,7 @@ PlayResult *playNode(ThreadData * local_td, Node * local_list,
     int zerocfbytes_count = 0;
     char url_copy[1024];
     int c;
+    char ch;
     int length_request_count = 0;
     float lastmedialength = -1.0;
     int lastmediapercent = -1;
@@ -822,7 +823,9 @@ PlayResult *playNode(ThreadData * local_td, Node * local_list,
 		if ((local_td->instance->cancelled == 0)
 		    && (local_td->instance->player != NULL)) {
 		    // c = fgetc(local_td->instance->player);
-		    amt = fread(&c, 1, 1, local_td->instance->player);
+                    // read a char here, otherwise reading int causes endian issue
+                    amt = fread(&ch, 1, 1, local_td->instance->player);
+                    c = amt == 1 ? ch : EOF;
 		} else {
 		    c = EOF;
 		    amt = 0;
