@@ -3227,6 +3227,20 @@ void nsPluginInstance::PlaylistClear(PRBool * _retval)
     }
 }
 
+void nsPluginInstance::SetOnClick(const char *event)
+{
+    if(mouseClickCallback != NULL) {
+            NPN_MemFree(mouseClickCallback);
+    }
+    mouseClickCallback = (char *)NPN_MemAlloc(strlen(event) +
+					  12);	 
+    if (strncasecmp(event, "javascript:", 11) == 0) {
+        snprintf(mouseClickCallback, strlen(event),"%s", event);
+    } else {
+        snprintf(mouseClickCallback, strlen(event)+12,"javascript:%s", event);
+    }
+}
+
 // ==============================
 // ! Scriptability related code !
 // ==============================
